@@ -1,16 +1,17 @@
 require 'spec_helper'
 
 describe 'cinder::client' do
-
   let :params do
     {}
   end
 
   let :default_params do
-    { :package_ensure   => 'present' }
+    {
+      :package_ensure => 'present'
+    }
   end
 
-  shared_examples_for 'cinder client' do
+  shared_examples 'cinder client' do
     let :p do
       default_params.merge(params)
     end
@@ -25,13 +26,7 @@ describe 'cinder::client' do
       )
     end
 
-    it 'installs openstackclient package' do
-      is_expected.to contain_package('python-openstackclient').with(
-        'ensure' => 'present',
-        'tag'    => 'openstack',
-      )
-    end
-
+    it { is_expected.to contain_class('openstacklib::openstackclient') }
   end
 
   on_supported_os({
@@ -45,17 +40,13 @@ describe 'cinder::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-cinderclient' }
-          else
-            { :client_package_name => 'python-cinderclient' }
-          end
+          { :client_package_name => 'python3-cinderclient' }
         when 'RedHat'
           { :client_package_name => 'python-cinderclient' }
         end
       end
 
-      it_configures 'cinder client'
+      it_behaves_like 'cinder client'
     end
   end
 end
