@@ -1,15 +1,14 @@
 require 'spec_helper'
 
 describe 'cinder::keystone::authtoken' do
-
   let :params do
-    { :password => 'cinder_password', }
+    {
+      :password => 'cinder_password',
+    }
   end
 
   shared_examples 'cinder authtoken' do
-
     context 'with default parameters' do
-
       it 'configure keystone_authtoken' do
         is_expected.to contain_cinder_config('keystone_authtoken/username').with_value('cinder')
         is_expected.to contain_cinder_config('keystone_authtoken/password').with_value('cinder_password')
@@ -25,10 +24,8 @@ describe 'cinder::keystone::authtoken' do
         is_expected.to contain_cinder_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('keystone_authtoken/check_revocations_for_cached').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/delay_auth_decision').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/enforce_token_bind').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('keystone_authtoken/hash_algorithms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/http_connect_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/http_request_max_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/include_service_catalog').with_value('<SERVICE DEFAULT>')
@@ -44,6 +41,7 @@ describe 'cinder::keystone::authtoken' do
         is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -64,10 +62,8 @@ describe 'cinder::keystone::authtoken' do
           :cache                                => 'somevalue',
           :cafile                               => '/opt/stack/data/cafile.pem',
           :certfile                             => 'certfile.crt',
-          :check_revocations_for_cached         => false,
           :delay_auth_decision                  => false,
           :enforce_token_bind                   => 'permissive',
-          :hash_algorithms                      => 'md5',
           :http_connect_timeout                 => '300',
           :http_request_max_retries             => '3',
           :include_service_catalog              => true,
@@ -84,6 +80,7 @@ describe 'cinder::keystone::authtoken' do
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :token_cache_time                     => '301',
+          :service_token_roles_required         => false,
         })
       end
 
@@ -102,10 +99,8 @@ describe 'cinder::keystone::authtoken' do
         is_expected.to contain_cinder_config('keystone_authtoken/cache').with_value(params[:cache])
         is_expected.to contain_cinder_config('keystone_authtoken/cafile').with_value(params[:cafile])
         is_expected.to contain_cinder_config('keystone_authtoken/certfile').with_value(params[:certfile])
-        is_expected.to contain_cinder_config('keystone_authtoken/check_revocations_for_cached').with_value(params[:check_revocations_for_cached])
         is_expected.to contain_cinder_config('keystone_authtoken/delay_auth_decision').with_value(params[:delay_auth_decision])
         is_expected.to contain_cinder_config('keystone_authtoken/enforce_token_bind').with_value(params[:enforce_token_bind])
-        is_expected.to contain_cinder_config('keystone_authtoken/hash_algorithms').with_value(params[:hash_algorithms])
         is_expected.to contain_cinder_config('keystone_authtoken/http_connect_timeout').with_value(params[:http_connect_timeout])
         is_expected.to contain_cinder_config('keystone_authtoken/http_request_max_retries').with_value(params[:http_request_max_retries])
         is_expected.to contain_cinder_config('keystone_authtoken/include_service_catalog').with_value(params[:include_service_catalog])
@@ -121,6 +116,7 @@ describe 'cinder::keystone::authtoken' do
         is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_cinder_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_cinder_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
+        is_expected.to contain_cinder_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
       end
 
       it 'installs python memcache package' do
@@ -137,8 +133,7 @@ describe 'cinder::keystone::authtoken' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'cinder authtoken'
+      it_behaves_like 'cinder authtoken'
     end
   end
-
 end
